==> haskell-text-short-0.1.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-text-short.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-short
version: 0.1.1
id: text-short-0.1.1-JcL3O9DvaGM5S9a5VHyIup
key: text-short-0.1.1-JcL3O9DvaGM5S9a5VHyIup
license: BSD3
maintainer: hvr@gnu.org
synopsis: Memory-efficient representation of Unicode text strings
description:
    This package provides the '\''ShortText'\'' type which is suitable for keeping many short strings in memory. This is similiar to how '\''ShortByteString'\'' relates to '\''ByteString'\''.
    .
    The main difference between '\''Text'\'' and '\''ShortText'\'' is that '\''ShortText'\'' uses UTF-8 instead of UTF-16 internally and also doesn'\''t support slicing (thereby saving 2 words). Consequently, the memory footprint of a (boxed) '\''ShortText'\'' value is 4 words (2 words when unboxed) plus the length of the UTF-8 encoded payload.
category: Data
author: Herbert Valerio Riedel
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Short Data.Text.Short.Unsafe
hidden-modules: Data.Text.Short.Internal
abi: a4f96c4163473b7a6b0f9eb77b092519
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/text-short-0.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/text-short-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/text-short-0.1.1
hs-libraries: HStext-short-0.1.1-JcL3O9DvaGM5S9a5VHyIup
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk deepseq-1.4.3.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz binary-0.8.5.1
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
haddock-interfaces: /usr/share/doc/haskell-text-short/html/text-short.haddock
haddock-html: /usr/share/doc/haskell-text-short/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-short-0.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-text-short.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-short
version: 0.1
id: text-short-0.1-A5My3POkYrKIsx4tZcD2Wl
key: text-short-0.1-A5My3POkYrKIsx4tZcD2Wl
license: BSD3
maintainer: hvr@gnu.org
synopsis: Memory-efficient representation of Unicode text strings
description:
    This package provides the '\''ShortText'\'' type which is suitable for keeping many short strings in memory. This is similiar to how '\''ShortByteString'\'' relates to '\''ByteString'\''.
    .
    The main difference between '\''Text'\'' and '\''ShortText'\'' is that '\''ShortText'\'' uses UTF-8 instead of UTF-16 internally and also doesn'\''t support slicing (thereby saving 2 words). Consequently, the memory footprint of a (boxed) '\''ShortText'\'' value is 4 words (2 words when unboxed) plus the length of the UTF-8 encoded payload.
category: Data
author: Herbert Valerio Riedel
exposed: True
exposed-modules:
    Data.Text.Short
abi: 2b11f73fae6c5d96607da2bf54a30071
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/text-short-0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/text-short-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/text-short-0.1
hs-libraries: HStext-short-0.1-A5My3POkYrKIsx4tZcD2Wl
depends:
    base-4.9.1.0 binary-0.8.3.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-text-short/html/text-short.haddock
haddock-html: /usr/share/doc/haskell-text-short/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
